@@ -102,6 +102,7 @@ def compute_distance_and_save(permutation_dataset: PermutationPairsDataset, hdfs
     log.info('Computing distances using {}...'.format(distance))
     completed = False
     error_idx = (0, 0, 0, 0)
+    repeat_count = 0
     while not completed:
         try:
             for s1, s2 in tqdm(data_loader):
@@ -130,11 +131,16 @@ def compute_distance_and_save(permutation_dataset: PermutationPairsDataset, hdfs
             log.error(e)
             log.error(traceback.format_exc())
             log.info('Last batch computed: ({}, {}) ~ ({}, {})'.format(idx1[0], idx2[0], idx1[-1], idx2[-1]))
+            if error_idx == (idx1[0], idx2[0], idx1[-1], idx2[-1]):
+                log.info("repeating the same batch...")
+                repeat_count +=1
+
         finally:
             del data_loader
             if not completed:
-                if error_idx == (idx1[0], idx2[0], idx1[-1], idx2[-1]):
-                    log.info("repeating the same batch... exiting the program")
+                if repeat_count > 1000:
+                    log.error("repeating the same batch over and over...")
+                    log.info("exiting...")
                     break
                 log.info('Restarting data loader from ({}, {})...'.format(idx1[0], idx2[0]))
                 error_idx = (idx1[0], idx2[0], idx1[-1], idx2[-1])
