@@ -18,6 +18,10 @@ class NetworkParams:
     num_workers: int
     gpu_num: int
 
+@dataclass
+class DistanceParams:
+    metric: str
+
 @dataclass
 class AnalysisParams:
     match_mode: str
@@ -39,4 +43,5 @@ class ShapeYConfig:
     data: DatasetConfig
     network: NetworkParams
     graph: AnalysisParams
-    pipeline: PipelineParams
\ No newline at end of file
+    pipeline: PipelineParams
+    distance: DistanceParams
\ No newline at end of file
